<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="134"/>
        <source>About</source>
        <translation type="unfinished">O</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="135"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="137"/>
        <source>Lightweight file manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="143"/>
        <source>PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="139"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="138"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="142"/>
        <source>Authors</source>
        <translation>Autoři</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="160"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="110"/>
        <source>Removable medium is inserted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="112"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="113"/>
        <source>Type of medium:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="114"/>
        <source>Detecting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="115"/>
        <source>Please select the action you want to perform:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="75"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="76"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="77"/>
        <source>Desktop folder:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="79"/>
        <source>Image file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="84"/>
        <source>Folder path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="85"/>
        <source>&amp;Browse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="254"/>
        <source>Desktop Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="255"/>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="256"/>
        <source>Wallpaper mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="257"/>
        <source>Wallpaper image file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="259"/>
        <source>Select background color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="261"/>
        <source>Image file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="266"/>
        <source>Image file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="267"/>
        <source>&amp;Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="268"/>
        <source>Label Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="271"/>
        <source>Select  text color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="272"/>
        <source>Select shadow color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="273"/>
        <source>Select font:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="275"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="276"/>
        <source>Window Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="277"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="278"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="557"/>
        <source>File Manager</source>
        <translation type="unfinished">Správce souborů</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="560"/>
        <source>Go Up</source>
        <translation type="unfinished">Nahoru</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="562"/>
        <source>Alt+Up</source>
        <translation type="unfinished">Alt+Nahoru</translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="obsolete">Domů</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="564"/>
        <source>Alt+Home</source>
        <translation type="unfinished">Alt+Home</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="583"/>
        <source>Reload</source>
        <translation type="unfinished">Obnovit</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="566"/>
        <source>F5</source>
        <translation type="unfinished">F5</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="563"/>
        <source>&amp;Home</source>
        <translation type="unfinished">&amp;Domů</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="565"/>
        <source>&amp;Reload</source>
        <translation type="unfinished">&amp;Obnovit</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="567"/>
        <source>Go</source>
        <translation type="unfinished">Jdi</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="568"/>
        <source>Quit</source>
        <translation type="unfinished">ukončit</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="569"/>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;O programu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="572"/>
        <source>New Window</source>
        <translation type="unfinished">Nové okno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="574"/>
        <source>Ctrl+N</source>
        <translation type="unfinished">Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="575"/>
        <source>Show &amp;Hidden</source>
        <translation type="unfinished">Zobrazit &amp;skryté</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="576"/>
        <source>Ctrl+H</source>
        <translation type="unfinished">Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="577"/>
        <source>&amp;Computer</source>
        <translation type="unfinished">P&amp;očítač</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="578"/>
        <source>&amp;Trash</source>
        <translation type="unfinished">&amp;Koš</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="579"/>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Síť</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="580"/>
        <source>&amp;Desktop</source>
        <translation type="unfinished">P&amp;locha</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="581"/>
        <source>&amp;Add to Bookmarks</source>
        <translation type="unfinished">&amp;Přidat k záložkám</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="582"/>
        <source>&amp;Applications</source>
        <translation type="unfinished">P&amp;rogramy</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="589"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="590"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovat</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="591"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="592"/>
        <source>&amp;Paste</source>
        <translation>&amp;Vložit</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="593"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="594"/>
        <source>Select &amp;All</source>
        <translation>Vybr&amp;at všechno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="596"/>
        <source>Pr&amp;eferences</source>
        <translation>&amp;Předvolby</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="597"/>
        <source>&amp;Ascending</source>
        <translation>&amp;Vzestupně</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="598"/>
        <source>&amp;Descending</source>
        <translation>&amp;Sesupně</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="599"/>
        <source>&amp;By File Name</source>
        <translation>Podle &amp;jména</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="600"/>
        <source>By &amp;Modification Time</source>
        <translation>Podle č&amp;asu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="601"/>
        <source>By File &amp;Type</source>
        <translation>Podle &amp;typu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="602"/>
        <source>By &amp;Owner</source>
        <translation>Podle v&amp;lastníka</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="603"/>
        <source>&amp;Folder First</source>
        <translation>&amp;Adresáře jako pvní</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="619"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Invertovat výběr</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="620"/>
        <source>&amp;Delete</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="622"/>
        <source>&amp;Rename</source>
        <translation>Pře&amp;jmenovat</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="629"/>
        <source>&amp;Case Sensitive</source>
        <translation>&amp;Zohlednit velikost písmen</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="630"/>
        <source>By File &amp;Size</source>
        <translation>Podle v&amp;elikosti</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="631"/>
        <source>&amp;Close Window</source>
        <translation type="unfinished">&amp;Zavřít okno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="595"/>
        <source>Ctrl+A</source>
        <translation type="unfinished">Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="558"/>
        <source>Go &amp;Up</source>
        <translation type="unfinished">&amp;Nahoru</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="570"/>
        <source>&amp;New Window</source>
        <translation type="unfinished">Nové &amp;okno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="584"/>
        <source>&amp;Icon View</source>
        <translation>&amp;Ikony</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="585"/>
        <source>&amp;Compact View</source>
        <translation>&amp;Kompaktní</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="586"/>
        <source>&amp;Detailed List</source>
        <translation>&amp;Podrobnosti</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="587"/>
        <source>&amp;Thumbnail View</source>
        <translation>&amp;Náhledy</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="588"/>
        <source>Cu&amp;t</source>
        <translation>V&amp;yjmout</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="obsolete">Vzestupně</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="obsolete">Sestupně</translation>
    </message>
    <message>
        <source>By File Name</source>
        <translation type="obsolete">Podle jména</translation>
    </message>
    <message>
        <source>By Modification Time</source>
        <translation type="obsolete">Podle času</translation>
    </message>
    <message>
        <source>By File Type</source>
        <translation type="obsolete">Podle typu</translation>
    </message>
    <message>
        <source>By Owner</source>
        <translation type="obsolete">Podle vlastníka</translation>
    </message>
    <message>
        <source>Folder First</source>
        <translation type="obsolete">Složky jako první</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="604"/>
        <source>New &amp;Tab</source>
        <translation type="unfinished">Nový &amp;panel</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="606"/>
        <source>New Tab</source>
        <translation type="unfinished">Nový panel</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="608"/>
        <source>Ctrl+T</source>
        <translation type="unfinished">Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="609"/>
        <source>Go &amp;Back</source>
        <translation type="unfinished">&amp;Zpět</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="611"/>
        <source>Go Back</source>
        <translation type="unfinished">Zpět</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="613"/>
        <source>Alt+Left</source>
        <translation type="unfinished">Alt+Vlevo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="614"/>
        <source>Go &amp;Forward</source>
        <translation type="unfinished">&amp;Vpřed</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="616"/>
        <source>Go Forward</source>
        <translation type="unfinished">Vpřed</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="618"/>
        <source>Alt+Right</source>
        <translation type="unfinished">Alt+Vpravo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="621"/>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="623"/>
        <source>F2</source>
        <translation type="unfinished">F2</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="624"/>
        <source>C&amp;lose Tab</source>
        <translation type="unfinished">Zavřít panel</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="626"/>
        <source>File &amp;Properties</source>
        <translation type="unfinished">Vlastnosti souboru</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="628"/>
        <source>&amp;Folder Properties</source>
        <translation type="unfinished">Vlastnosti složky</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="638"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="640"/>
        <source>Ctrl+Alt+N</source>
        <translation>Ctrl+Alt+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="643"/>
        <source>Filter</source>
        <translation>Filtrovat</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="646"/>
        <source>C&amp;reate New</source>
        <translation>Vytvořit &amp;nový</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="649"/>
        <source>&amp;Sorting</source>
        <translation type="unfinished">Ř&amp;adit</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="654"/>
        <source>Main Toolbar</source>
        <translation type="unfinished">Hlavní panel</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="625"/>
        <source>Ctrl+W</source>
        <translation type="unfinished">Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="627"/>
        <source>Alt+Return</source>
        <translation type="unfinished">Alt+Return</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation type="obsolete">Rozlišovat velikost písmen</translation>
    </message>
    <message>
        <source>By File Size</source>
        <translation type="obsolete">Podle velikosti</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="obsolete">Zavřít okno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="632"/>
        <source>Edit Bookmarks</source>
        <translation type="unfinished">Upravit záložky</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="633"/>
        <source>Open &amp;Terminal</source>
        <translation type="unfinished">Otevřít &amp;terminál</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="634"/>
        <source>F4</source>
        <translation type="unfinished">F4</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="635"/>
        <source>Open as &amp;Root</source>
        <translation type="unfinished">Otevřít jako &amp;Root</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="636"/>
        <source>&amp;Edit Bookmarks</source>
        <translation type="unfinished">&amp;Upravit záložky</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="637"/>
        <source>&amp;Folder</source>
        <translation type="unfinished">&amp;Složku</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="639"/>
        <source>&amp;Blank File</source>
        <translation type="unfinished">&amp;Prázdný soubor</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="641"/>
        <source>&amp;Find Files</source>
        <translation type="unfinished">Najít soubory</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="642"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="644"/>
        <source>Filter by string...</source>
        <translation>Filtrovat podle řetězce...</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="645"/>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Soubor</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="647"/>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Nápověda</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="648"/>
        <source>&amp;View</source>
        <translation type="unfinished">&amp;Zobrazení</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="650"/>
        <source>&amp;Edit</source>
        <translation type="unfinished">Úpr&amp;avy</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="651"/>
        <source>&amp;Bookmarks</source>
        <translation type="unfinished">Zál&amp;ožky</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="652"/>
        <source>&amp;Go</source>
        <translation type="unfinished">&amp;Jdi</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="653"/>
        <source>&amp;Tool</source>
        <translation type="unfinished">Nás&amp;troje</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="162"/>
        <source>Name of configuration profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="162"/>
        <source>PROFILE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="165"/>
        <source>Run PCManFM as a daemon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="168"/>
        <source>Quit PCManFM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="171"/>
        <source>Launch desktop manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="174"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <location filename="../application.cpp" line="193"/>
        <source>NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="180"/>
        <source>Open new window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="183"/>
        <source>Open Find Files utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>FILE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>Set mode of desktop wallpaper. MODE=(color|stretch|fit|center|tile)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>MODE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="193"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>Files or directories to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>[FILE1, FILE2,...]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="500"/>
        <location filename="../application.cpp" line="507"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="507"/>
        <source>Terminal emulator is not set.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="43"/>
        <source>Open in file manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="133"/>
        <source>Removable Disk</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="50"/>
        <source>Fill with background color only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="51"/>
        <source>Stretch to fill the entire screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="52"/>
        <source>Stretch to fit the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="53"/>
        <source>Center on the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="54"/>
        <source>Tile the image to fill the entire screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="157"/>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="366"/>
        <source>Stic&amp;k to Current Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="388"/>
        <source>Desktop Preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Clear text (Ctrl+K)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="455"/>
        <source>Version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>&amp;Move to Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="969"/>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Switch user command is not set.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="190"/>
        <source>Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="191"/>
        <source>Compact Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="192"/>
        <source>Thumbnail View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="193"/>
        <source>Detailed List View</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="248"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="261"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="276"/>
        <source>%n item(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="278"/>
        <source> (%n hidden)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="426"/>
        <source>%1 item(s) selected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="103"/>
        <source>Open in New T&amp;ab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../view.cpp" line="107"/>
        <source>Open in New Win&amp;dow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="706"/>
        <source>Preferences</source>
        <translation>Předvolby</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="715"/>
        <source>User Interface</source>
        <translation>Uživatelské rozhraní</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="711"/>
        <source>Behavior</source>
        <translation>Chování</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="717"/>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="779"/>
        <source>Thumbnail</source>
        <translation>Náhled</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="719"/>
        <source>Volume</source>
        <translation>Úložiště</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="721"/>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="742"/>
        <source>Icons</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="744"/>
        <source>Size of big icons:</source>
        <translation>Velikost velkých ikon:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="745"/>
        <source>Size of small icons:</source>
        <translation>Velikost malých ikon:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="746"/>
        <source>Size of thumbnails:</source>
        <translation>Velikost náhledů:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="747"/>
        <source>Size of side pane icons:</source>
        <translation>Velikost ikon v postranním panelu:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="743"/>
        <source>Icon theme:</source>
        <translation>Téma ikon:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="753"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="757"/>
        <source>Default width of new windows:</source>
        <translation>Výchozí šířka nových oken:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="758"/>
        <source>Default height of new windows:</source>
        <translation>Výchozí výška nových oken:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="754"/>
        <source>Always show the tab bar</source>
        <translation>Vždycky zobrazovat lištu s panely</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="755"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>Zobrazovat tlačítko &apos;Zavřít&apos; na panelech	</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="756"/>
        <source>Remember the size of the last closed window</source>
        <translation>Pamatovat si rozměry naposedy zavřeného okna</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="724"/>
        <source>Browsing</source>
        <translation>Prohlížení</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="725"/>
        <source>Open files with single click</source>
        <translation>Otvírat soubory jedním kliknutím</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="726"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>Zpoždění automatického výběru v jednoklikacím režimu (0 pro zákaz)</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="727"/>
        <source>Default view mode:</source>
        <translation>Výchozí režim pohledu:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="728"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="736"/>
        <source>File Operations</source>
        <translation>Operace se soubory</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="737"/>
        <source>Confirm before deleting files</source>
        <translation>Potvrdit mazání souborů</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="738"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>Přesunout mazané soubory do koše místo smazání z disku.</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="783"/>
        <source>Show thumbnails of files</source>
        <translation>Zobrazovat náhledy souborů</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="782"/>
        <source>Only show thumbnails for local files</source>
        <translation>Zobrazovat náhled jen u lokálních souborů</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="713"/>
        <source>Display</source>
        <translation>Zobrazení</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="729"/>
        <source>Bookmarks:</source>
        <translation>Záložky:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="732"/>
        <source>Open in current tab</source>
        <translation>Otvírat v současném panelu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="733"/>
        <source>Open in new tab</source>
        <translation>Otvírat v novém panelu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="734"/>
        <source>Open in new window</source>
        <translation>Otvírat v novém okně</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="739"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="740"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="741"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="748"/>
        <source>User interface</source>
        <translation>Uživatelské rozhraní</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="750"/>
        <source>Treat backup files as hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="751"/>
        <source>Always show full file names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="752"/>
        <source>Show icons of hidden files shadowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="759"/>
        <source>Show in places</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="764"/>
        <source>Home</source>
        <translation type="unfinished">Domů</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="766"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="768"/>
        <source>Trash can</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="770"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="772"/>
        <source>Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="774"/>
        <source>Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="776"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="780"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>Negenerovat náhledy obrázků přesahujících tuto velikost:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="781"/>
        <source> KB</source>
        <translation> KB</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="784"/>
        <source>Auto Mount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="785"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>Připojit přenosná úložiště automaticky při startu programu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="786"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Připojit přenosná úložiště automaticky když jsou vložena</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="787"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Zobrazit pokročilé volby pro přenosná úložiště když jsou vložena</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="788"/>
        <source>When removable medium unmounted:</source>
        <translation>Když je přenosné úložiště odpojeno:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="789"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>&amp;Zavřít panel obsahující přenosné úložiště</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="790"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>Změnit adresář v panelu na &amp;domovský</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="793"/>
        <source>Switch &amp;user command:</source>
        <translation>Příkaz k přepnutí &amp;uživatele:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="796"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>Propojení s &amp;archivátorem:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="797"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="798"/>
        <source>Show only user defined templates in menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="799"/>
        <source>Show only one template for each MIME type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="800"/>
        <source>Run default application after creation from template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="791"/>
        <source>Programs</source>
        <translation>Programy</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="792"/>
        <source>Terminal emulator:</source>
        <translation>Emulátor terminálu:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="794"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation type="unfinished">Příklady: &quot;xterm -e %s&quot; pro terminál nebo &quot;gksu %s&quot; pro přepnutí uživatele.
%s = příkazový řádek, který chceš spustit terminálem nebo su.</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="749"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
